# lpshipit

[![Snap Status](https://build.snapcraft.io/badge/philroche/lpshipit.svg)](https://build.snapcraft.io/user/philroche/lpshipit)

Helpful utility for merging launchpad MPs (only works for git repos)
